@@ -15,6 +15,7 @@ from .extras import Exctras
 from .gif import Gifs
 from .voice_chat import VoiceCall
 from .links import Links
+from .live import Lives
 
 
 class Methods(
@@ -33,6 +34,7 @@ class Methods(
     Exctras,
     Gifs,
     VoiceCall,
-    Links
+    Links,
+    Lives
 ):
     pass
